@@ -6,12 +6,14 @@ import gettext
 import io
 import json
 import logging
-import namedlist
 import os
 import tempfile
 import time
+
+import namedlist
 import tornado.gen
 
+import wpull.async
 from wpull.conversation import Body
 from wpull.database import Status
 from wpull.document import HTMLReader
@@ -23,6 +25,7 @@ from wpull.item import LinkType
 from wpull.namevalue import NameValueRecord
 from wpull.scraper import HTMLScraper, DemuxDocumentScraper, CSSScraper
 from wpull.stats import Statistics
+import wpull.string
 from wpull.url import URLInfo
 from wpull.urlfilter import DemuxURLFilter, SpanHostsFilter
 import wpull.util
@@ -247,11 +250,11 @@ class WebProcessorSession(object):
 
             is_done = yield self._process_one()
 
-            wait_time = self._processor.instances.waiter.get()
+            wait_time = self._get_wait_time()
 
             if wait_time:
                 _logger.debug('Sleeping {0}.'.format(wait_time))
-                yield wpull.util.sleep(wait_time)
+                yield wpull.async.sleep(wait_time)
 
             if is_done:
                 break
@@ -370,9 +373,11 @@ class WebProcessorSession(object):
 
     def _add_post_data(self, request):
         if self._url_item.url_record.post_data:
-            data = wpull.util.to_bytes(self._url_item.url_record.post_data)
+            data = wpull.string.to_bytes(self._url_item.url_record.post_data)
         else:
-            data = wpull.util.to_bytes(self._processor.fetch_params.post_data)
+            data = wpull.string.to_bytes(
+                self._processor.fetch_params.post_data
+            )
 
         request.method = 'POST'
         request.fields['Content-Type'] = 'application/x-www-form-urlencoded'
@@ -485,15 +490,8 @@ class WebProcessorSession(object):
 
     def _scrape_document(self, request, response):
         '''Scrape the document for URLs.'''
-        try:
-            demux_info = self._processor.instances\
-                .document_scraper.scrape_info(request, response)
-        except UnicodeError as error:
-            _logger.warning(
-                _('Failed to decode document at ‘{url}’: {error}.')\
-                .format(url=request.url_info.url, error=error)
-            )
-            return
+        demux_info = self._processor.instances\
+            .document_scraper.scrape_info(request, response)
 
         num_inline_urls = 0
         num_linked_urls = 0
@@ -566,6 +564,10 @@ class WebProcessorSession(object):
         and instance.body.content_file:
             instance.body.content_file.close()
 
+    def _get_wait_time(self):
+        '''Return the wait time.'''
+        return self._processor.instances.waiter.get()
+
     @tornado.gen.coroutine
     def _process_phantomjs(self, request, response):
         '''Process PhantomJS.'''
@@ -751,7 +753,7 @@ class PhantomJSController(object):
             total_scroll_count += 1
 
             self._log_action('wait', self._wait_time)
-            yield wpull.util.sleep(self._wait_time)
+            yield wpull.async.sleep(self._wait_time)
 
             post_scroll_counter_values = remote.resource_counter.values()
 
@@ -769,7 +771,7 @@ class PhantomJSController(object):
         for dummy in range(remote.resource_counter.pending):
             if remote.resource_counter.pending:
                 self._log_action('wait', self._wait_time)
-                yield wpull.util.sleep(self._wait_time)
+                yield wpull.async.sleep(self._wait_time)
             else:
                 break
 
